<?php
/**
 * @file
 * Contains \Drupal\restui\Controller\RestUIController.
 */

namespace Drupal\restui\Controller;

use Drupal\Core\Controller\ControllerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

use Drupal\restui\RestUIManager;

/**
 * Controller routines for REST resources.
 */
class RestUIController implements ControllerInterface {

  /**
   * Rest UI Manager Service.
   *
   * @var \Drupal\restui\RestUIManager
   */
  protected $restUIManager;

  /**
   * Injects RestUIManager Service.
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('restui.manager'));
  }

  /**
   * Constructs a RestUIController object.
   */
  public function __construct(RestUIManager $restUIManager) {
    $this->restUIManager = $restUIManager;
  }

  /**
   * Returns an administrative overview of all REST resources.
   *
   * @return string
   *   A HTML-formatted string with the administrative page content.
   *
   */
  public function adminOverview() {
    $rows = array();

    $headers = array(t('Entity'));

    // Add any recognized books to the table list.
    foreach ($this->restUIManager->getAllResources() as $resource) {
      $row = array($resource['name']);
      $rows[] = $row;
    }
    $table = array('#theme' => 'table', '#header' => $headers, '#rows' => $rows, '#empty' => t('No resources available.'));
    return drupal_render($table);
  }

}
